@@ -3,9 +3,9 @@ from .files import *
 from .xml_to_csv import *
 from .recipe import *
 from .generate_tfrecords import csv_to_tfrecord
-from .tf_models import get_models
+from .tf_models import *
 """Top-level package for cookiepy."""
 
 __author__ = """Nikos Koumbakis"""
 __email__ = 'n.koumbakis@gmail.com'
-__version__ = '0.9.2'
+__version__ = '0.9.4'
